if Network:is_client() then
	return
end

if not Global.game_settings or Global.game_settings.level_id ~= 'nmh' then
	return
end

core:module("CoreMissionScriptElement")
core:import("CoreXml")
core:import("CoreCode")
core:import("CoreClass")

MissionScriptElement = MissionScriptElement or class()
local override_func = MissionScriptElement.on_executed

local room = 0
local room_opened = 0
local escape_available = false
local stealth_active = true

_G.NMHS = _G.NMHS or class()

_G.NMHS.civ_call_cnt = 0

_G.NMHS.doors_closed_org = false

_G.NMHS.phone_reset = false
_G.NMHS.phone_interacted_cnt = 0
_G.NMHS.phone_dialog_np_cnt = 0
_G.NMHS.phone_civ_event = true
_G.NMHS.phone_completed_org = false

function _G.NMHS:alerted_vip()
	if stealth_active then
		local event = managers.mission:get_element_by_id(103434)
		event:on_executed()
		stealth_active = false
	end
end

function contains_executed(list, id)
	for _, event in pairs(list) do
		if tostring(event.id) == id then
			return true
		end
	end
	return false
end

function MissionScriptElement:on_executed(...)
	local id = tostring(self._id)

	--alarm
	if (id == '102863' or id == '103225' or id == '102859' or id == '102607' or id == '104751') and stealth_active  then
		self._values.enabled = false --no alarm for stealth
	end
	if id == '102551' then
		stealth_active = false --stealth disabled
	end

	--players and AI
	if id == '102604' and not contains_executed(self._values.on_executed, '103727') then
		table.insert(self._values.on_executed,{id=103727,delay=0}) --use doctor outfits
	end
	if id == '103727' then
		self._values.on_executed = {} --don't change team relation
	end
	if id == '104455' then
		self._values.enabled = false --don't unmask AI
	end
	
	--custom elevator events
	if id == '102831' and _G.NMHS.doors_closed_org == true then
		self._values.on_executed = {} --remove other events from door closing
	end
	if id == '102714' then
		_G.NMHS.doors_closed_org = true --door closed at beginning
	end
	if id == '103736' then
		self._values.on_executed[2].id = 102605 --open booth doors on left civ spawn
	end
	if  id == '103740' then
		self._values.on_executed[1].id = 102605 --open both doors on right civ spawn
	end
	if id == '102605' and _G.NMHS.doors_closed_org == true then
		if not contains_executed(self._values.on_executed, '102831') then
			table.insert(self._values.on_executed,{id=102831,delay=7}) --close doors on civ spawn
		end
	end

	--custom phone events
	if id == '102623' and not contains_executed(self._values.on_executed, '102717') then
		self._values.on_executed = {}
		_G.NMHS.phone_reset = true
		table.insert(self._values.on_executed,{id=102717,delay=0}) --reset phone call chance
		table.insert(self._values.on_executed,{id=102650,delay=0}) --start telephone event again
	end
	if id == '102699' or id == '102698' or id == '102687' then
		self._values.trigger_times = 2 --keep events alive for continuous phone call
	end
	if id == '103747' or id == '103748' or id == '103735' or id == '103739' or id == '102697' then
		self._values.trigger_times = 2 --keep events alive for continuous civ spawns
	end
	if id == '102697' and not contains_executed(self._values.on_executed, '103741') then
		table.insert(self._values.on_executed,{id=103741,delay=0}) --spawn civ on dialog
	end
	if id == '102681' and escape_available then
		self._values.enabled = false --disable phone when leaving
	end

	--open ICU after search is over
	if id == '103973' and not contains_executed(self._values.on_executed, '105392') then
		table.insert(self._values.on_executed,{id=105392,delay=0}) --initialize patients
		table.insert(self._values.on_executed,{id=102776,delay=0}) --load ICU area
		table.insert(self._values.on_executed,{id=102578,delay=0}) --remove dev block
	end

	--skip sentries
	if id == '102754' then
		self._values.enabled = false --skip sentries mission
	end
	if id == '130472' and not contains_executed(self._values.on_executed, '130772') then
		self._values.on_executed = {}
		table.insert(self._values.on_executed,{id=130772,delay=0}) --skip sentries objective
	end
	
	--track new objectives
	if (id == '102885' or id == '102884' or id == '102883') and not contains_executed(self._values.on_executed, '131072') then
		table.insert(self._values.on_executed,{id=131072,delay=0}) --update objective "draw blood"
	end
	if id == '102875' and not contains_executed(self._values.on_executed, '131522') then
		table.insert(self._values.on_executed,{id=131522,delay=0}) --update objective "go to roof"
	end
	if id == '104572' and not contains_executed(self._values.on_executed, '131672') then
		table.insert(self._values.on_executed,{id=131672,delay=0}) --update objective "open hatch"
	end
	if id == '103427' and not contains_executed(self._values.on_executed, '131822') then
		table.insert(self._values.on_executed,{id=131822,delay=0}) --update objective "escape"
	end
	if id == '130922' then
		self._values.enabled = false --disable skipped objective
	end

	--stop female doc after wire cut
	if id == '102849' and not contains_executed(self._values.on_executed, '102848') then
		table.insert(self._values.on_executed,{id=102848,delay=0})
		table.insert(self._values.on_executed,{id=102864,delay=0})
	end

	if stealth_active then
		--close security doors if wrong room has been opened
		if id == '104333' and room_opened == 0 and not contains_executed(self._values.on_executed, '102843') then
			table.insert(self._values.on_executed,{id=102843,delay=0})
			room_opened = 102345
		end
		if id == '104335' and room_opened == 0 and not contains_executed(self._values.on_executed, '102843') then
			table.insert(self._values.on_executed,{id=102843,delay=0})
			room_opened = 102844
		end
		if id == '104334' and room_opened == 0 and not contains_executed(self._values.on_executed, '102843') then
			table.insert(self._values.on_executed,{id=102843,delay=0})
			room_opened = 102845
		end

		if id == '102843' and contains_executed(self._values.on_executed, tostring(room_opened)) then
			--don't close security door on opened room
			if room_opened == 102345 then
				table.remove(self._values.on_executed,1)
			end
			if room_opened == 102844 then
				table.remove(self._values.on_executed,2)
			end
			if room_opened == 102845 then
				table.remove(self._values.on_executed,3)
			end
		end
	end

	--open elevator on first sample
	if id == '103624' and not contains_executed(self._values.on_executed, '103439') then
		table.insert(self._values.on_executed,{id=103439,delay=0}) --call elevator
		table.insert(self._values.on_executed,{id=131372,delay=0}) --update objective
	end
	--remove patient waypoint
	if id == '103524' and not contains_executed(self._values.on_executed, '103521') then
		table.insert(self._values.on_executed,{id=103521,delay=0})
	end
	--trigger basement ending
	if id == '103022' and not contains_executed(self._values.on_executed, '104620') then
		self._values.on_executed = {}
		escape_available = true
		table.insert(self._values.on_executed,{id=103322,delay=0}) --play sound
		table.insert(self._values.on_executed,{id=104620,delay=0}) --enable events
		table.insert(self._values.on_executed,{id=103424,delay=0}) --enable crowbar
	end

	--disable loud elevator events
	if id == '103425' and contains_executed(self._values.on_executed, '103843') then
		table.remove(self._values.on_executed,2) --disable point of no return
	end
	if id == '103431' and contains_executed(self._values.on_executed, '103434') then
		table.remove(self._values.on_executed,1) --disable point of no return
	end
	if id == '104191' and contains_executed(self._values.on_executed, '104170') then
		self._values.on_executed = {} --disable sound and earthquake
	end

	override_func(self, ...)
end